@@ -28,6 +28,7 @@
 #include <avogadro/qtgui/moleculemodel.h>
 #include <avogadro/qtgui/multiviewwidget.h>
 #include <avogadro/qtgui/periodictableview.h>
+#include <avogadro/qtgui/richtextdelegate.h>
 #include <avogadro/qtgui/rwmolecule.h>
 #include <avogadro/qtgui/sceneplugin.h>
 #include <avogadro/qtgui/scenepluginmodel.h>
@@ -46,6 +47,7 @@
 #include <QtCore/QMimeData>
 #include <QtCore/QProcess>
 #include <QtCore/QSettings>
+#include <QtCore/QSortFilterProxyModel>
 #include <QtCore/QStandardPaths>
 #include <QtCore/QString>
 #include <QtCore/QThread>
@@ -96,13 +98,6 @@
 #include <avogadro/vtk/vtkglwidget.h>
 #endif
 
-#if defined(Q_OS_MAC) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#include "qcocoamessagebox.h"
-#define MESSAGEBOX QCocoaMessageBox
-#else
-#define MESSAGEBOX QMessageBox
-#endif
-
 namespace Avogadro {
 
 #ifdef QTTESTING
@@ -418,6 +413,9 @@ void MainWindow::setupInterface()
       settings.value("MainWindow/ao_strength", 1.0f).toFloat());
     pipeline->setEdEnabled(
       settings.value("MainWindow/ed_enabled", false).toBool());
+
+    // set background color
+    pipeline->setBackgroundColor(cColor);
   }
 
   // Our tool dock.
@@ -430,6 +428,7 @@ void MainWindow::setupInterface()
   m_sceneTreeView->setIndentation(0);
   m_sceneTreeView->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_sceneTreeView->setSelectionMode(QAbstractItemView::SingleSelection);
+  m_sceneTreeView->setSortingEnabled(true);
   m_sceneDock->setWidget(m_sceneTreeView);
   addDockWidget(Qt::LeftDockWidgetArea, m_sceneDock);
 
@@ -438,9 +437,11 @@ void MainWindow::setupInterface()
   addDockWidget(Qt::LeftDockWidgetArea, m_viewDock);
 
   // Our molecule dock.
-  m_moleculeDock = new QDockWidget(tr("Molecules"), this);
+  m_moleculeDock = new QDockWidget(tr("Files"), this);
   m_moleculeTreeView = new QTreeView(m_moleculeDock);
   m_moleculeTreeView->setIndentation(0);
+  m_moleculeTreeView->setItemDelegateForColumn(
+    0, new QtGui::RichTextDelegate(m_moleculeTreeView));
   m_moleculeTreeView->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_moleculeTreeView->setSelectionMode(QAbstractItemView::SingleSelection);
   m_moleculeDock->setWidget(m_moleculeTreeView);
@@ -462,8 +463,13 @@ void MainWindow::setupInterface()
   m_moleculeDock->raise();
 
   // Switch to our fallback icons if there are no platform-specific icons.
-  if (!QIcon::hasThemeIcon("document-new"))
+  if (!QIcon::hasThemeIcon("document-new")) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    QIcon::setFallbackThemeName("fallback");
+#else
     QIcon::setThemeName("fallback");
+#endif
+  }
 
   QIcon icon(":/icons/avogadro.png");
   setWindowIcon(icon);
@@ -540,6 +546,30 @@ void MainWindow::closeEvent(QCloseEvent* e)
   QMainWindow::closeEvent(e);
 }
 
+void MainWindow::changeEvent(QEvent* e)
+{
+  // it's supposed to be through a theme change
+  // but on macOS, it seems to be triggered
+  // by a palette change, so we handle both
+  if (e->type() == QEvent::ApplicationPaletteChange ||
+      e->type() == QEvent::PaletteChange || e->type() == QEvent::ThemeChange) {
+    e->accept();
+
+    const QPalette defaultPalette;
+    // is the text lighter than the window color?
+    bool darkMode = (defaultPalette.color(QPalette::WindowText).lightness() >
+                     defaultPalette.color(QPalette::Window).lightness());
+
+    // Handle theme changes by telling tools to update their icons.
+    for (ToolPlugin* tool : m_tools) {
+      if (tool != nullptr)
+        tool->setIcon(darkMode);
+    }
+  }
+
+  QMainWindow::changeEvent(e);
+}
+
 void MainWindow::dragEnterEvent(QDragEnterEvent* event)
 {
   if (event->mimeData()->hasUrls())
@@ -561,9 +591,14 @@ void MainWindow::dropEvent(QDropEvent* event)
         if (extension == "py")
           addScript(fileName);
         else
-          openFile(fileName);
+          // add these to m_queuedFiles
+          // so we can read them later
+          m_queuedFiles.append(fileName);
       }
     }
+    if (!m_queuedFiles.empty())
+      readQueuedFiles();
+
     event->acceptProposedAction();
   } else
     event->ignore();
@@ -770,9 +805,9 @@ void MainWindow::setLocale(const QString& locale)
     settings.setValue("locale", locale);
   }
 
-  MESSAGEBOX::information(this, tr("Restart needed"),
-                          tr("Please restart Avogadro to use the new "
-                             "language."));
+  QMessageBox::information(this, tr("Restart needed"),
+                           tr("Please restart Avogadro to use the new "
+                              "language."));
 }
 
 void MainWindow::readSettings()
@@ -816,8 +851,8 @@ void MainWindow::openFile()
     reader = new Io::CjsonFormat;
 
   if (!openFile(fileName, reader)) {
-    MESSAGEBOX::information(this, tr("Cannot open file"),
-                            tr("Can't open supplied file %1").arg(fileName));
+    QMessageBox::information(this, tr("Cannot open file"),
+                             tr("Can't open supplied file %1").arg(fileName));
   }
 }
 
@@ -839,7 +874,7 @@ void MainWindow::importFile()
   settings.setValue("MainWindow/lastOpenDir", dir);
 
   if (!openFile(reply.second, reply.first->newInstance())) {
-    MESSAGEBOX::information(
+    QMessageBox::information(
       this, tr("Cannot open file"),
       tr("Can't open supplied file %1").arg(reply.second));
   }
@@ -948,6 +983,7 @@ bool MainWindow::openFile(const QString& fileName, Io::FileFormat* reader)
   // Prepare the background thread to read in the selected file.
   if (!m_fileReadThread)
     m_fileReadThread = new QThread(this);
+
   if (m_threadedReader)
     m_threadedReader->deleteLater();
   m_threadedReader = new BackgroundFileFormat(reader);
@@ -1031,10 +1067,10 @@ void MainWindow::backgroundReaderFinished()
                                .arg(m_molecule->bondCount()),
                              5000);
   } else {
-    MESSAGEBOX::critical(this, tr("File error"),
-                         tr("Error while reading file '%1':\n%2")
-                           .arg(fileName)
-                           .arg(m_threadedReader->error()));
+    QMessageBox::critical(this, tr("File error"),
+                          tr("Error while reading file '%1':\n%2")
+                            .arg(fileName)
+                            .arg(m_threadedReader->error()));
     delete m_fileReadMolecule;
   }
   m_fileReadThread->deleteLater();
@@ -1065,7 +1101,7 @@ bool MainWindow::backgroundWriterFinished()
       updateWindowTitle();
       success = true;
     } else {
-      MESSAGEBOX::critical(
+      QMessageBox::critical(
         this, tr("Error saving file"),
         tr("Error while saving '%1':\n%2", "%1 = file name, %2 = error message")
           .arg(fileName)
@@ -1106,9 +1142,9 @@ void MainWindow::viewConfigActivated() {}
 void MainWindow::rendererInvalid()
 {
   auto* widget = qobject_cast<GLWidget*>(sender());
-  MESSAGEBOX::warning(this, tr("Error: Failed to initialize OpenGL context"),
-                      tr("OpenGL 2.0 or greater required, exiting.\n\n%1")
-                        .arg(widget ? widget->error() : tr("Unknown error")));
+  QMessageBox::warning(this, tr("Error: Failed to initialize OpenGL context"),
+                       tr("OpenGL 2.0 or greater required, exiting.\n\n%1")
+                         .arg(widget ? widget->error() : tr("Unknown error")));
   // Process events, and then set a single shot timer. This is needed to ensure
   // the RPC server also exits cleanly.
   QApplication::processEvents();
@@ -1190,10 +1226,27 @@ void MainWindow::sceneItemActivated(const QModelIndex& idx)
 {
   if (!idx.isValid())
     return;
-  auto* obj = static_cast<QObject*>(idx.internalPointer());
-  if (auto* scene = qobject_cast<ScenePlugin*>(obj)) {
-    m_viewDock->setWidget(scene->setupWidget());
-    m_activeScenePlugin = scene;
+
+  QSortFilterProxyModel* proxyModel =
+    qobject_cast<QSortFilterProxyModel*>(m_sceneTreeView->model());
+  if (!proxyModel)
+    return;
+
+  // get the source index
+  QModelIndex sourceIdx = proxyModel->mapToSource(idx);
+  if (!sourceIdx.isValid())
+    return;
+
+  QWidget* w = m_multiViewWidget->activeWidget();
+  if (auto* glWidget = qobject_cast<QtOpenGL::GLWidget*>(w)) {
+    const ScenePluginModel* sceneModel = &glWidget->sceneModel();
+    if (sceneModel == nullptr)
+      return;
+
+    if (auto* plugin = sceneModel->scenePlugin(sourceIdx.row())) {
+      m_viewDock->setWidget(plugin->setupWidget());
+      m_activeScenePlugin = plugin;
+    }
   }
 }
 
@@ -1245,7 +1298,13 @@ void MainWindow::viewActivated(QWidget* widget)
   ActiveObjects::instance().setActiveWidget(widget);
   if (auto* glWidget = qobject_cast<GLWidget*>(widget)) {
     bool firstRun = populatePluginModel(glWidget->sceneModel(), this);
-    m_sceneTreeView->setModel(&glWidget->sceneModel());
+    QSortFilterProxyModel* proxyModel = new QSortFilterProxyModel(this);
+
+    proxyModel->setSourceModel(&glWidget->sceneModel());
+    m_sceneTreeView->setModel(proxyModel);
+    m_sceneTreeView->setSortingEnabled(true);
+    // column 1 is the name, column 0 is the checkbox
+    m_sceneTreeView->sortByColumn(0, Qt::AscendingOrder);
     // tweak the size of columns
     m_sceneTreeView->header()->setSectionResizeMode(1, QHeaderView::Fixed);
     m_sceneTreeView->header()->resizeSection(1, 40);
@@ -1391,8 +1450,8 @@ void MainWindow::exportGraphics(QString fileName)
   QImage exportImage = renderToImage(size);
 
   if (!exportImage.save(fileName)) {
-    MESSAGEBOX::warning(this, tr("Avogadro"),
-                        tr("Cannot save file %1.").arg(fileName));
+    QMessageBox::warning(this, tr("Avogadro"),
+                         tr("Cannot save file %1.").arg(fileName));
   }
 }
 
@@ -1422,8 +1481,8 @@ void MainWindow::openRecentFile()
                                        FileFormat::File | FileFormat::Read);
 
     if (!openFile(fileName, format ? format->newInstance() : nullptr)) {
-      MESSAGEBOX::information(this, tr("Cannot open file"),
-                              tr("Can't open supplied file %1").arg(fileName));
+      QMessageBox::information(this, tr("Cannot open file"),
+                               tr("Can't open supplied file %1").arg(fileName));
     }
   }
 }
@@ -1506,7 +1565,7 @@ bool MainWindow::saveFile(bool async)
        .empty();
   if (writable) {
     // Warn the user that the format may lose data.
-    MESSAGEBOX box(this);
+    QMessageBox box(this);
     box.setModal(true);
     box.setWindowTitle(tr("Avogadro"));
     box.setText(tr("This file was imported from a non-standard format which "
@@ -1984,7 +2043,9 @@ void MainWindow::buildMenu()
   // New
   auto* action = new QAction(tr("&New"), this);
   action->setShortcut(QKeySequence::New);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+  action->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::DocumentNew));
+#else
   action->setIcon(QIcon::fromTheme("document-new"));
 #endif
   m_menuBuilder->addAction(path, action, 999);
@@ -1993,7 +2054,9 @@ void MainWindow::buildMenu()
   // Open
   action = new QAction(tr("&Open…"), this);
   action->setShortcut(QKeySequence::Open);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+  action->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::DocumentOpen));
+#else
   action->setIcon(QIcon::fromTheme("document-open"));
 #endif
   m_menuBuilder->addAction(path, action, 998);
@@ -2002,9 +2065,7 @@ void MainWindow::buildMenu()
 
   action = new QAction(tr("&Close"), this);
   action->setShortcut(QKeySequence::Close);
-#ifndef Q_OS_MAC
   action->setIcon(QIcon::fromTheme("document-close"));
-#endif
   m_menuBuilder->addAction(path, action, 981);
   m_fileToolBar->addAction(action);
   connect(action, &QAction::triggered, this, &QWidget::close);
@@ -2013,19 +2074,25 @@ void MainWindow::buildMenu()
   action = new QAction("", this);
   action->setSeparator(true);
   m_menuBuilder->addAction(path, action, 980);
+
   // Save
   action = new QAction(tr("&Save"), this);
   action->setShortcut(QKeySequence::Save);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+  action->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::DocumentSave));
+#else
   action->setIcon(QIcon::fromTheme("document-save"));
 #endif
   m_menuBuilder->addAction(path, action, 965);
   m_fileToolBar->addAction(action);
   connect(action, &QAction::triggered, this, &MainWindow::saveFile);
+
   // Save As
   action = new QAction(tr("Save &As…"), this);
   action->setShortcut(QKeySequence::SaveAs);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+  action->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::DocumentSaveAs));
+#else
   action->setIcon(QIcon::fromTheme("document-save-as"));
 #endif
   m_menuBuilder->addAction(path, action, 960);
@@ -2073,7 +2140,9 @@ void MainWindow::buildMenu()
   for (int i = 0; i < 10; ++i) {
     action = new QAction(QString::number(i), this);
     m_actionRecentFiles.push_back(action);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    action->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::DocumentOpenRecent));
+#else
     action->setIcon(QIcon::fromTheme("document-open-recent"));
 #endif
     action->setVisible(false);
@@ -2088,12 +2157,17 @@ void MainWindow::buildMenu()
   QStringList editPath;
   editPath << tr("&Edit");
   m_undo = new QAction(tr("&Undo"), this);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+  m_undo->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::EditUndo));
+#else
   m_undo->setIcon(QIcon::fromTheme("edit-undo"));
 #endif
   m_undo->setShortcut(QKeySequence::Undo);
+
   m_redo = new QAction(tr("&Redo"), this);
-#ifndef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+  m_redo->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::EditRedo));
+#else
   m_redo->setIcon(QIcon::fromTheme("edit-redo"));
 #endif
   m_redo->setShortcut(QKeySequence::Redo);
@@ -2169,9 +2243,7 @@ void MainWindow::buildMenu()
   QStringList helpPath;
   helpPath << tr("&Help");
   auto* about = new QAction(tr("&About"), this);
-#ifndef Q_OS_MAC
   about->setIcon(QIcon::fromTheme("help-about"));
-#endif
   m_menuBuilder->addAction(helpPath, about, 500);
   connect(about, &QAction::triggered, this, &MainWindow::showAboutDialog);
 
@@ -2349,7 +2421,7 @@ bool MainWindow::saveFileIfNeeded()
     // the static functions. This is more work, but gives us some nice
     // fine-grain control. This helps both on Windows and Mac
     // look more "native."
-    QPointer<MESSAGEBOX> msgBox = new MESSAGEBOX(
+    QMessageBox msgBox(
       QMessageBox::Warning, tr("Avogadro"),
       tr("Do you want to save the changes to the document?"),
       QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel, this);
@@ -2358,20 +2430,17 @@ bool MainWindow::saveFileIfNeeded()
     // Unfortunately, it also closes the window when the box disappears!
     // msgBox->setWindowModality(Qt::WindowModal);
     // second line of text
-    msgBox->setInformativeText(
+    msgBox.setInformativeText(
       tr("Your changes will be lost if you don't save them."));
-    msgBox->setDefaultButton(QMessageBox::Save);
-#ifdef Q_OS_MAC
-    msgBox->setWindowModality(Qt::WindowModal);
-#endif
+    msgBox.setDefaultButton(QMessageBox::Save);
 
     // OK, now add shortcuts for save and discard
-    msgBox->button(QMessageBox::Save)
+    msgBox.button(QMessageBox::Save)
       ->setShortcut(QKeySequence(tr("Ctrl+S", "Save")));
-    msgBox->button(QMessageBox::Discard)
+    msgBox.button(QMessageBox::Discard)
       ->setShortcut(QKeySequence(tr("Ctrl+D", "Discard")));
 
-    int response = msgBox->exec();
+    int response = msgBox.exec();
 
     switch (static_cast<QMessageBox::StandardButton>(response)) {
       case QMessageBox::Save:
@@ -2456,8 +2525,8 @@ void MainWindow::checkUpdate()
 void MainWindow::finishUpdateRequest(QNetworkReply* reply)
 {
   if (!reply->isReadable()) {
-    MESSAGEBOX::warning(this, tr("Network Download Failed"),
-                        tr("Network timeout or other error."));
+    QMessageBox::warning(this, tr("Network Download Failed"),
+                         tr("Network timeout or other error."));
     reply->deleteLater();
     return;
   }
@@ -2503,9 +2572,9 @@ void MainWindow::finishUpdateRequest(QNetworkReply* reply)
   QString text =
     tr("An update is available, do you want to download it now?\n");
   text += currentVersion + '\n' + newVersion;
-  auto result = MESSAGEBOX::information(this, tr("Version Update"), text,
-                                        QMessageBox::Ok | QMessageBox::Ignore |
-                                          QMessageBox::Cancel);
+  auto result = QMessageBox::information(this, tr("Version Update"), text,
+                                         QMessageBox::Ok | QMessageBox::Ignore |
+                                           QMessageBox::Cancel);
 
   if (result == QMessageBox::Cancel)
     return;
@@ -2581,10 +2650,10 @@ void MainWindow::readQueuedFiles()
       "Avogadro:");
 
     if (!openFile(file, format ? format->newInstance() : nullptr)) {
-      MESSAGEBOX::warning(this, tr("Cannot open file"),
-                          tr("Avogadro cannot open"
-                             " “%1”.")
-                            .arg(file));
+      QMessageBox::warning(this, tr("Cannot open file"),
+                           tr("Avogadro cannot open"
+                              " “%1”.")
+                             .arg(file));
     }
   }
 }
@@ -2592,10 +2661,10 @@ void MainWindow::readQueuedFiles()
 void MainWindow::clearQueuedFiles()
 {
   if (!m_queuedFilesStarted && !m_queuedFiles.isEmpty()) {
-    MESSAGEBOX::warning(this, tr("Cannot open files"),
-                        tr("Avogadro cannot open"
-                           " “%1”.")
-                          .arg(m_queuedFiles.join("\n")));
+    QMessageBox::warning(this, tr("Cannot open files"),
+                         tr("Avogadro cannot open"
+                            " “%1”.")
+                           .arg(m_queuedFiles.join("\n")));
     m_queuedFiles.clear();
   }
 }
